@@ -1,12 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2017-2022 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2017-2023 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.57;
+use warnings;
+use Object::Pad 0.800;
 
-package Device::Chip::LTC2400 0.14;
+package Device::Chip::LTC2400 0.15;
 class Device::Chip::LTC2400
    :isa(Device::Chip);
 
@@ -18,7 +19,7 @@ use constant PROTOCOL => "SPI";
 
 C<Device::Chip::LTC2400> - chip driver for F<LTC2400>
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 This L<Device::Chip> subclass provides specific communications to a
 F<Linear Technologies> F<LTC2400> chip attached to a computer via an SPI
